


<h1 align="center"> Nulis Automate </h1>

<p align="center">
    <img src="image (1).png" width="200px" style="border-radius:6%"><br><br>
    <img src="https://visitor-badge.glitch.me/badge?page_id=krypton-byte.repo.302807305">&nbsp;<img src="https://img.shields.io/badge/dynamic/json?color=%23fc034e&label=forks&logo=github&query=%24.length&url=https%3A%2F%2Fapi.github.com%2Frepos%2Fkrypton-byte%2Ftulis-module%2Fforks"> <img src="https://img.shields.io/badge/dynamic/json?color=%23181717&label=stars&logo=github&query=%24.length&url=https%3A%2F%2Fapi.github.com%2Frepos%2Fkrypton-byte%2Ftulis-module%2Fstargazers">  <a href="https://pypi.org/project/tulis/"><img src="https://img.shields.io/badge/PyPi-tulis-%233775A9?logo=pypi"><br></a>
</p>

# installation

```bash
$ pip3 install tulis
```
# how to use

```bash
$ python3
```
```python
>>> from nulis import tulis
>>> for i in tulis("Nama : Krypton-Byte", worker=10):
>>>     i.show() #show image
>>>     i.save("catatan.jpg") #save the results
```
```Automatic support for new lines when it reaches the right end and adding paper when not enough```

# Result
<img src="catatan.jpg">
